/****************************************************************************
** Meta object code from reading C++ file 'kabstractconfigmodule.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kcmutils-6.28.0/src/core/kabstractconfigmodule.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kabstractconfigmodule.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN21KAbstractConfigModuleE_t {};
} // unnamed namespace

template <> constexpr inline auto KAbstractConfigModule::qt_create_metaobjectdata<qt_meta_tag_ZN21KAbstractConfigModuleE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KAbstractConfigModule",
        "authActionNameChanged",
        "",
        "needsSaveChanged",
        "representsDefaultsChanged",
        "buttonsChanged",
        "defaultsIndicatorsVisibleChanged",
        "supportsInstantApplyChanged",
        "activationRequested",
        "QVariantList",
        "args",
        "buttons",
        "KAbstractConfigModule::Buttons",
        "defaultsIndicatorsVisible",
        "needsAuthorization",
        "representsDefaults",
        "needsSave",
        "name",
        "description",
        "supportsInstantApply",
        "Button",
        "NoAdditionalButton",
        "Help",
        "Default",
        "Apply",
        "Export",
        "Buttons"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'authActionNameChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'needsSaveChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'representsDefaultsChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'buttonsChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'defaultsIndicatorsVisibleChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'supportsInstantApplyChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'activationRequested'
        QtMocHelpers::SignalData<void(const QVariantList &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'buttons'
        QtMocHelpers::PropertyData<KAbstractConfigModule::Buttons>(11, 0x80000000 | 12, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 3),
        // property 'defaultsIndicatorsVisible'
        QtMocHelpers::PropertyData<bool>(13, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'needsAuthorization'
        QtMocHelpers::PropertyData<bool>(14, QMetaType::Bool, QMC::DefaultPropertyFlags, 0),
        // property 'representsDefaults'
        QtMocHelpers::PropertyData<bool>(15, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'needsSave'
        QtMocHelpers::PropertyData<bool>(16, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'name'
        QtMocHelpers::PropertyData<QString>(17, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'description'
        QtMocHelpers::PropertyData<QString>(18, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'supportsInstantApply'
        QtMocHelpers::PropertyData<bool>(19, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Button'
        QtMocHelpers::EnumData<enum Button>(20, 20, QMC::EnumFlags{}).add({
            {   21, Button::NoAdditionalButton },
            {   22, Button::Help },
            {   23, Button::Default },
            {   24, Button::Apply },
            {   25, Button::Export },
        }),
        // flag 'Buttons'
        QtMocHelpers::EnumData<Buttons>(26, 20, QMC::EnumIsFlag).add({
            {   21, Button::NoAdditionalButton },
            {   22, Button::Help },
            {   23, Button::Default },
            {   24, Button::Apply },
            {   25, Button::Export },
        }),
    };
    return QtMocHelpers::metaObjectData<KAbstractConfigModule, qt_meta_tag_ZN21KAbstractConfigModuleE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KAbstractConfigModule::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21KAbstractConfigModuleE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21KAbstractConfigModuleE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN21KAbstractConfigModuleE_t>.metaTypes,
    nullptr
} };

void KAbstractConfigModule::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KAbstractConfigModule *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->authActionNameChanged(); break;
        case 1: _t->needsSaveChanged(); break;
        case 2: _t->representsDefaultsChanged(); break;
        case 3: _t->buttonsChanged(); break;
        case 4: _t->defaultsIndicatorsVisibleChanged(); break;
        case 5: _t->supportsInstantApplyChanged(); break;
        case 6: _t->activationRequested((*reinterpret_cast<std::add_pointer_t<QVariantList>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KAbstractConfigModule::*)()>(_a, &KAbstractConfigModule::authActionNameChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KAbstractConfigModule::*)()>(_a, &KAbstractConfigModule::needsSaveChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (KAbstractConfigModule::*)()>(_a, &KAbstractConfigModule::representsDefaultsChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (KAbstractConfigModule::*)()>(_a, &KAbstractConfigModule::buttonsChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (KAbstractConfigModule::*)()>(_a, &KAbstractConfigModule::defaultsIndicatorsVisibleChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (KAbstractConfigModule::*)()>(_a, &KAbstractConfigModule::supportsInstantApplyChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (KAbstractConfigModule::*)(const QVariantList & )>(_a, &KAbstractConfigModule::activationRequested, 6))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<KAbstractConfigModule::Buttons*>(_v) = _t->buttons(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->defaultsIndicatorsVisible(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->needsAuthorization(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->representsDefaults(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->needsSave(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->description(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->supportsInstantApply(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setButtons(*reinterpret_cast<KAbstractConfigModule::Buttons*>(_v)); break;
        case 1: _t->setDefaultsIndicatorsVisible(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setRepresentsDefaults(*reinterpret_cast<bool*>(_v)); break;
        case 4: _t->setNeedsSave(*reinterpret_cast<bool*>(_v)); break;
        case 7: _t->setSupportsInstantApply(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *KAbstractConfigModule::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KAbstractConfigModule::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21KAbstractConfigModuleE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KAbstractConfigModule::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void KAbstractConfigModule::authActionNameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KAbstractConfigModule::needsSaveChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void KAbstractConfigModule::representsDefaultsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void KAbstractConfigModule::buttonsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void KAbstractConfigModule::defaultsIndicatorsVisibleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void KAbstractConfigModule::supportsInstantApplyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void KAbstractConfigModule::activationRequested(const QVariantList & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}
QT_WARNING_POP
